Range-v3: ranges::v3::range_facade< Derived, Cardinality > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | Protected Types | Protected Member Functions | Protected Attributes | List of all members
ranges::v3::range_facade< Derived, Cardinality > Struct Template Reference
Core
Inheritance diagram for ranges::v3::range_facade< Derived, Cardinality >:

## Public Member Functions
template<typename D = Derived, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
detail::facade_iterator_t< D > | begin ()
template<typename D = Derived, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
detail::facade_iterator_t< D const > | begin () const
template<typename D = Derived, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
detail::facade_sentinel_t< D > | end ()
template<typename D = Derived, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
detail::facade_sentinel_t< D const > | end () const
Public Member Functions inherited from ranges::v3::range_interface< Derived, Cardinality >
template<typename D = Derived, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()&&BoundedView< D >()&&BidirectionalView< D >()), int >::type = 0>
range_reference_t< D > | back ()
| Access the last element in a range:
template<typename D = Derived, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()&&BoundedView< D const >()&&BidirectionalView< D const >()), int >::type = 0>
range_reference_t< D const > | back () const
constexpr bool | empty () const
template<typename D = Derived, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
range_reference_t< D > | front ()
| Access the first element in a range:
template<typename D = Derived, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
range_reference_t< D const > | front () const
constexpr | operator bool () const
template<typename Container , typename D = Derived, typename Alloc = typename Container::allocator_type, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(detail::ConvertibleToContainer< D, Container >()), int >::type = 0>
| operator Container ()
| Implicit conversion to something that looks like a container.
template<typename Container , typename D = Derived, typename Alloc = typename Container::allocator_type, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(detail::ConvertibleToContainer< D const, Container >()), int >::type = 0>
| operator Container () const
constexpr bool | operator! () const
template<typename D = Derived, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()&&RandomAccessView< D >()), int >::type = 0>
auto | operator[] (range_difference_t< D > n) -> decltype(std::declval< D & >().begin()[n])
| Simple indexing:
template<typename D = Derived, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()&&RandomAccessView< D const >()), int >::type = 0>
auto | operator[] (range_difference_t< D > n) const -> decltype(std::declval< D const & >().begin()[n])
template<typename D = Derived, typename Slice = view::slice_fn, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
auto | operator[] (detail::slice_bounds< range_difference_t< D >> offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
| Python-ic slicing:
template<typename D = Derived, typename Slice = view::slice_fn, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
auto | operator[] (detail::slice_bounds< range_difference_t< D >> offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
auto | operator[] (detail::slice_bounds< range_difference_t< D >, detail::from_end_< range_difference_t< D >>> offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
auto | operator[] (detail::slice_bounds< range_difference_t< D >, detail::from_end_< range_difference_t< D >>> offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_t< D >>, detail::from_end_< range_difference_t< D >>> offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_t< D >>, detail::from_end_< range_difference_t< D >>> offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
auto | operator[] (detail::slice_bounds< range_difference_t< D >, end_fn > offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
auto | operator[] (detail::slice_bounds< range_difference_t< D >, end_fn > offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_t< D >>, end_fn > offs) -> decltype(std::declval< Slice >()(std::declval< D & >(), offs.from, offs.to))
template<typename D = Derived, typename Slice = view::slice_fn, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>
auto | operator[] (detail::slice_bounds< detail::from_end_< range_difference_t< D >>, end_fn > offs) const -> decltype(std::declval< Slice >()(std::declval< D const & >(), offs.from, offs.to))
template<typename D = Derived, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()&&(Cardinality > = 0 || SizedIteratorRange<range_iterator_t<D>, range_sentinel_t<D>>()>
constexpr range_size_t< D > | size () const
| Access the size of the range, if it can be determined:

## Protected Types
using | range_facade_t = range_facade

## Protected Member Functions
Derived | begin_cursor () const
default_sentinel | end_cursor () const
Protected Member Functions inherited from ranges::v3::range_interface< Derived, Cardinality >
Derived & | derived ()
Derived const & | derived () const

## Protected Attributes
friend | range_access

## Member Function Documentation

template<typename Derived, cardinality Cardinality>
template<typename D = Derived, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>

detail::facade_iterator_t<D const> ranges::v3::range_facade< Derived, Cardinality >::begin | ( |  | ) | const

This is an overloaded member function, provided for convenience. It differs from the above function only in what argument(s) it accepts.

template<typename Derived, cardinality Cardinality>
template<typename D = Derived, int _concept_requires___LINE__ = 42, typename std::enable_if< (_concept_requires___LINE__==43)||(Same< D, Derived >()), int >::type = 0>

detail::facade_sentinel_t<D const> ranges::v3::range_facade< Derived, Cardinality >::end | ( |  | ) | const

This is an overloaded member function, provided for convenience. It differs from the above function only in what argument(s) it accepts.